# Table of Contents

- [matrix-report](<./matrix-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Matrix Report](<./Matrix-Report.md>)
  - [How is it useful?](<./Matrix-Report/How-is-it-useful.md>)
  - [Using Matrix Reports](<./Matrix-Report/Using-Matrix-Reports.md>)
  - [Filters, Views, and Levels](<./Matrix-Report/Filters-Views-and-Levels.md>)
  - [Drill-Down](<./Matrix-Report/Drill-Down.md>)
  - [Views on Drilled-Down Fact Sheets](<./Matrix-Report/Views-on-Drilled-Down-Fact-Sheets.md>)
  - [Layout Modes](<./Matrix-Report/Layout-Modes.md>)
  - [Editing in Matrix Reports](<./Matrix-Report/Editing-in-Matrix-Reports.md>)
  - [Was this page helpful?](<./Matrix-Report/Was-this-page-helpful.md>)
